include<LX15D.scad>;

screw_d = 3;
t = 2;

z_screw_offset = 36;
main_screw_offset = LX15D_clearance_r + t;

module main_screw_pos() {
    for (z = [ -0.5, 0.5 ])
        translate([ main_screw_offset, 0, z * z_screw_offset ])
            rotate([ -90, 0, 0 ]) children();
}

module side_screw_pos(femurOffset) {
    translate(femurOffset) rotate([ 90, 0, 180 ]) {
        LX15D_bottom_screw_pos() children();
    }
    rotate([ -90, 0, 0 ]) LX15D_screw_plane() {
        rotate([ 90, 0, 0 ]) main_screw_pos() children();
    }
}

module M3_screw(l, center = false) { cylinder(d = 3, h = l, center = center); }

module side_plate(femurOffset) {
    relative_screw_offset = [ femurOffset[0] - main_screw_offset, 0, 0 ];
    translate(femurOffset) rotate([ 90, 0, 180 ]) LX15D_side_plate(
        screw_d,
        [
            relative_screw_offset + [ 0, z_screw_offset / 2, 0 ],
            relative_screw_offset - [ 0, z_screw_offset / 2, 0 ]
        ],
        t);
}

cable_clearance_radius = 2;
cable_clearance_d = 3;
cable_clearance_h = LX15D_screw_y;
cable_clearance_w = cable_clearance_d / 2 + t;
cable_clearance_x = 10;

module cable_side_plate() difference() {
    union() {
        rotate([ 90, 0, 180 ]) hull()
            LX15D_bottom_screw_pos() for (x = [ 0, -1.5 ])
                translate([ x, 0, t ]) {
            cylinder(d = LX15D_screw_clearance_d,
                     h = cable_clearance_w - t + LX15D_middle_t);
        }
        translate([ LX15D_axis_offset - LX15D_dim[0], LX15D_dim[2] / 2, 0 ])
            translate([ cable_clearance_x, LX15D_middle_t, 0 ]) difference() {
            union() {
                cube(
                    [
                        cable_clearance_d + t * 3, cable_clearance_w * 2,
                        cable_clearance_h
                    ],
                    center = true);
            }
            translate([ 0, -50, 0 ]) cube(100, center = true);
            difference() {
                cube(
                    [
                        cable_clearance_d + cable_clearance_radius * 2,
                        cable_clearance_d + cable_clearance_radius * 2, 30
                    ],
                    center = true);
                rotate_extrude(convexity = 10) hull() for (i = [ -0.5, 0.5 ])
                    translate([
                        cable_clearance_radius + cable_clearance_d,
                        i * (cable_clearance_h - cable_clearance_radius * 2), 0
                    ]) circle(r = cable_clearance_radius);
            }
        }
    }
    rotate([ 90, 0, 180 ]) LX15D_bottom_screw_pos()
        cylinder(d = LX15D_body_screw_d, h = 100, center = true);
}

module holder() difference() {
    a = screw_d + t * 2;
    hull() {
        LX15D_horn_screw_pos() translate([ 0, 0, LX15D_horn_w / 2 ])
            cylinder(d = a, h = t);

        translate([ main_screw_offset, 0, z_screw_offset / 2 ])
            rotate([ 90, 0, 0 ])
                cylinder(d = a, h = LX15D_dim[2], center = true);
    }
    LX15D_clearance();

    LX15D_horn_screw_pos() translate([ 0, 0, LX15D_horn_w / 2 ])
        cylinder(d = screw_d, h = 100, center = true);

    cylinder(d = LX15D_horn_clearance_d, h = 100, center = true);

    translate([ main_screw_offset, 0, z_screw_offset / 2 ]) rotate([ 90, 0, 0 ])
        cylinder(d = screw_d, h = 100, center = true);
}

module coxa_holder(femurOffset) {
    for (m = [ 0, 1 ]) mirror([ 0, 0, m ]) holder();

    for (m = [ 0, 1 ]) mirror([ 0, m, 0 ]) side_plate(femurOffset);
    translate(femurOffset) cable_side_plate();
}

module coxa_collision(femurOffset) {
    width = LX15D_dim[2] + t * 2;
    translate([ femurOffset[0] / 2, 0, 0 ]) cube(
        [ femurOffset[0] + width, width, LX15D_horn_w + t * 2 ], center = true);
}

$fs = 0.5;
$fa = 0.5;

module coxa(femurOffset) {
    color("red") coxa_holder(femurOffset);

    translate(femurOffset) rotate([ 90, 0, 180 ]) LX15D();
}

coxa([ 55, 0, 0 ]);
