include<LX15D.scad>;

t = 3;
screw_d = 3;
tube_d = 6;

screw_a = 18;
screw_x_offset = 6;

function screw_coord(i) = [
    LX15D_dim[0] - LX15D_axis_offset + screw_x_offset,  //
    (floor(i / 2) - 0.5) * LX15D_dim[2],                //
    ((i % 2) - 0.5) *
    screw_a
];

function line_interp(from, to, f) = [
    (to[0] - from[0]) * f + from[0],
    (to[1] - from[1]) * f + from[1],
    (to[2] - from[2]) * f + from[2] + sin(f * 180) * 2,
];

function line_coord(i) = screw_coord(i) + [ 0, -4 * floor(i / 2) + 2, 0 ];

module line(from, to, t) {
    hull() {
        translate(from) sphere(d = t);
        translate(to) sphere(d = t);
    }
}

module level(tipOffset, f, step) {
    for (c = [ [ 0, 1 ], [ 1, 3 ], [ 3, 2 ], [ 2, 0 ] ]) {
        A = line_interp(line_coord(c[0]), tipOffset, f);
        line(A, line_interp(line_coord(c[1]), tipOffset, f), t);
        line(A, line_interp(line_coord(c[0]), tipOffset, f - step), t);
    }
}

module screw_pos(pos) {
    for (i = pos) translate(screw_coord(i)) rotate([ 90, 0, 0 ]) children();
}

module tibia_plate() difference() {
    relative_offset =
        [ LX15D_dim[0] - LX15D_axis_offset + screw_x_offset, 0, 0 ];
    rotate([ 90, 0, 0 ])
        LX15D_side_plate(screw_d,
                         [
                             relative_offset + [ 0, screw_a / 2, 0 ],
                             relative_offset - [ 0, screw_a / 2, 0 ]
                         ],
                         t);
}

module tip(tipOffset) difference() {
    step = 1 / 8;
    union() {
        for (c = [ [ 0, 1 ], [ 1, 3 ], [ 3, 2 ], [ 2, 0 ] ]) {
            A = line_interp(line_coord(c[0]), tipOffset, 0);
            line(A, line_interp(line_coord(c[1]), tipOffset, 0), t);
        }
        for (f = [step:step:1]) {
            level(tipOffset, f, step);
        }
        screw_pos([ 0, 1 ]) rotate([ 180, 0, 0 ])
            cylinder(d = screw_d + t * 2, h = LX15D_dim[2]);
    }
    screw_pos([ 0, 1, 2, 3 ]) cylinder(d = screw_d, h = 100, center = true);
}

$fa = 0.5;
$fs = 0.5;

module tibia(tipOffset) {
    color("yellow") {
        for (m = [ 0, 1 ]) mirror([ 0, m, 0 ]) tibia_plate();
        tip(tipOffset);
    }
    rotate([ 90, 0, 0 ]) LX15D();
}

module tibia_collision(tipOffset) hull() {
    translate([ LX15D_axis_offset, 0, 0 ]) rotate([ 90, 0, 0 ])
        cube([ LX15D_dim[0], LX15D_dim[1], LX15D_horn_w ], center = true);

    translate(tipOffset) cube(1, center = true);
}

tibia([ 100, 0, 0 ]);
